@@ -32,3 +32,5 @@ __author__ = 'Eclipse Tractus-X Contributors'
 __license__ = "Apache License, Version 2.0"
 
 from .postgres_connection_manager import PostgresConnectionManager
+from .postgres_memory_refresh_connection_manager import PostgresMemoryRefreshConnectionManager
+from .postgres_memory_connection_manager import PostgresMemoryConnectionManager
\ No newline at end of file
